torchcut
========

Shortcut for common PyTorch related imports.


Usage
-----

Install via pip:
```bash
pip install torchcut
```

Use torchcut to import the most common packages for PyTorch related projects with one line:
```python
from torchcut import *

# Will expose
# - torch
# - torch.nn as nn
# - torch.nn.functional as F
# - torch.optim as optim

# Optionally, if installed:
# - torchvision as tv
# - torchvision.transforms as transforms
#
# - torchtext as tt
#
# - numpy as np
# - pandas as pd
```
